summaryrefslogtreecommitdiffstats
path: root/nova
diff options
context:
space:
mode:
authorMichael Gundlach <michael.gundlach@rackspace.com>2010-08-16 10:57:42 -0400
committerMichael Gundlach <michael.gundlach@rackspace.com>2010-08-16 10:57:42 -0400
commit5c4a806c852a1c7180bc1c7e2ea8f065198e36d2 (patch)
tree344d5841bfea11588a6d68b21308d18a2d9d247e /nova
parentbfb906cb0235a6e0b037d387aadc4abc2280fea0 (diff)
PEP8 and name corrections
Diffstat (limited to 'nova')
-rw-r--r--nova/endpoint/aws/__init__.py4
-rw-r--r--nova/endpoint/rackspace/__init__.py10
-rw-r--r--nova/endpoint/rackspace/controllers/base.py4
-rw-r--r--nova/wsgi.py4
4 files changed, 11 insertions, 11 deletions
diff --git a/nova/endpoint/aws/__init__.py b/nova/endpoint/aws/__init__.py
index f49270a30..4507cae62 100644
--- a/nova/endpoint/aws/__init__.py
+++ b/nova/endpoint/aws/__init__.py
@@ -4,7 +4,7 @@ import webob.dec
from nova import wsgi
# TODO(gundlach): temp
-class Api(wsgi.Router):
+class API(wsgi.Router):
"""WSGI entry point for all AWS API requests."""
def __init__(self):
@@ -14,7 +14,7 @@ class Api(wsgi.Router):
targets = {"dummy": self.dummy }
- super(Api, self).__init__(mapper, targets)
+ super(API, self).__init__(mapper, targets)
@webob.dec.wsgify
def dummy(self, req):
diff --git a/nova/endpoint/rackspace/__init__.py b/nova/endpoint/rackspace/__init__.py
index f14f6218c..162b35caa 100644
--- a/nova/endpoint/rackspace/__init__.py
+++ b/nova/endpoint/rackspace/__init__.py
@@ -37,12 +37,12 @@ FLAGS = flags.FLAGS
flags.DEFINE_string('cloud_topic', 'cloud', 'the topic clouds listen on')
-class Api(wsgi.Middleware):
+class API(wsgi.Middleware):
"""WSGI entry point for all Rackspace API requests."""
def __init__(self):
- app = AuthMiddleware(ApiRouter())
- super(Api, self).__init__(app)
+ app = AuthMiddleware(APIRouter())
+ super(API, self).__init__(app)
class AuthMiddleware(wsgi.Middleware):
@@ -66,7 +66,7 @@ class AuthMiddleware(wsgi.Middleware):
return self.application
-class ApiRouter(wsgi.Router):
+class APIRouter(wsgi.Router):
"""
Routes requests on the Rackspace API to the appropriate controller
and method.
@@ -87,4 +87,4 @@ class ApiRouter(wsgi.Router):
'sharedipgroups': controllers.SharedIpGroupsController()
}
- super(ApiRouter, self).__init__(mapper, targets)
+ super(APIRouter, self).__init__(mapper, targets)
diff --git a/nova/endpoint/rackspace/controllers/base.py b/nova/endpoint/rackspace/controllers/base.py
index 3ada53fd4..8cd44f62e 100644
--- a/nova/endpoint/rackspace/controllers/base.py
+++ b/nova/endpoint/rackspace/controllers/base.py
@@ -1,6 +1,6 @@
-from nova.wsgi import WSGIController
+from nova import wsgi
-class BaseController(WSGIController):
+class BaseController(wsgi.Controller):
@classmethod
def render(cls, instance):
if isinstance(instance, list):
diff --git a/nova/wsgi.py b/nova/wsgi.py
index 0570e1829..52e155101 100644
--- a/nova/wsgi.py
+++ b/nova/wsgi.py
@@ -146,7 +146,7 @@ class Router(object):
Each route in `mapper` must specify a 'controller' string, which is
a key into the 'targets' dictionary whose value is a WSGI app to
run. If routing to a WSGIController, you'll want to specify
'action' as well so the controller knows what method to call on
itself.
@@ -195,7 +195,7 @@ class Router(object):
return app
-class WSGIController(object):
+class Controller(object):
"""
WSGI app that reads routing information supplied by RoutesMiddleware
and calls the requested action method on itself.
@@ -146,7 +146,7 @@ class Router(object):
Each route in `mapper` must specify a 'controller' string, which is
a key into the 'targets' dictionary whose value is a WSGI app to
- run. If routing to a WSGIController, you'll want to specify
+ run. If routing to a wsgi.Controller, you'll want to specify
'action' as well so the controller knows what method to call on
itself.